@@ -7,10 +7,10 @@ import streamlit.components.v1 as components
 _RELEASE = environ.get("RELEASE", "FALSE")
 
 
-class PageMenuItem(TypedDict):
+class MenuItem(TypedDict):
     key: str
     label: str
-    children: List["PageMenuItem"]
+    children: List["MenuItem"]
 
 
 if _RELEASE.lower() == "true":
@@ -20,5 +20,5 @@ else:
     _pages_menu = components.declare_component("pages_menu", path=build_dir.as_posix())
 
 
-def pages_menu(items: List[PageMenuItem]) -> str:
+def pages_menu(items: List[MenuItem]) -> str:
     return _pages_menu(items=items)
